@@ -723,15 +723,25 @@ class Construct(metaclass=jsii.JSIIMeta, jsii_type="constructs.Construct"):
     @jsii.member(jsii_name="isConstruct") # type: ignore[misc]
     @builtins.classmethod
     def is_construct(cls, x: typing.Any) -> builtins.bool:
-        '''(deprecated) Checks if ``x`` is a construct.
+        '''Checks if ``x`` is a construct.
+
+        Use this method instead of ``instanceof`` to properly detect ``Construct``
+        instances, even when the construct library is symlinked.
+
+        Explanation: in JavaScript, multiple copies of the ``constructs`` library on
+        disk are seen as independent, completely different libraries. As a
+        consequence, the class ``Construct`` in each copy of the ``constructs`` library
+        is seen as a different class, and an instance of one class will not test as
+        ``instanceof`` the other class. ``npm install`` will not create installations
+        like this, but users may manually symlink construct libraries together or
+        use a monorepo tool: in those cases, multiple copies of the ``constructs``
+        library can be accidentally installed, and ``instanceof`` will behave
+        unpredictably. It is safest to avoid using ``instanceof``, and using
+        this type-testing method instead.
 
         :param x: Any object.
 
         :return: true if ``x`` is an object created from a class which extends ``Construct``.
-
-        :deprecated: use ``x instanceof Construct`` instead
-
-        :stability: deprecated
         '''
         return typing.cast(builtins.bool, jsii.sinvoke(cls, "isConstruct", [x]))
 
